@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.090-7-ge8007de
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.091-9-gf92b8f1
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 # vim: set ts=8 sts=4 sw=4 tw=78 et :
 
-our $VERSION = '0.091';
+our $VERSION = '0.092';
 
 use Moose;
 with
@@ -141,7 +141,7 @@ sub configure
 
     my @plugins = (
         # VersionProvider
-        [ 'RewriteVersion::Transitional' => { ':version' => '0.004', fallback_version_provider => 'Git::NextVersion', version_regexp => '^v([\d._]+)(-TRIAL)?$',
+        [ 'RewriteVersion::Transitional' => { ':version' => '0.004', global => 1, fallback_version_provider => 'Git::NextVersion', version_regexp => '^v([\d._]+)(-TRIAL)?$',
                 (map { (my $key = $_) =~ s/Git::NextVersion\.//; $key => $self->payload->{$_} } grep { /^Git::NextVersion\./ } keys %{ $self->payload }) } ],
 
         # BeforeBuild
@@ -213,7 +213,7 @@ sub configure
         [ 'AuthorityFromModule' => { ':version' => '0.002' } ],
         [ 'Authority'           => { authority => 'cpan:ETHER', do_munging => 0 } ],
         [ 'MetaNoIndex'         => { directory => [ qw(t xt), grep { -d } qw(inc local perl5 fatlib examples share corpus demo) ] } ],
-        [ 'MetaProvides::Package' => { meta_noindex => 1, ':version' => '1.15000002', finder => ':InstallModules' } ],
+        [ 'MetaProvides::Package' => { ':version' => '1.15000002', finder => ':InstallModules', meta_noindex => 1, inherit_version => 0, inherit_missing => 1 } ],
         'MetaConfig',
         [ 'Keywords'            => { ':version' => '0.004' } ],
         [ 'Git::Contributors'   => { ':version' => '0.004', order_by => 'commits' } ],
@@ -271,9 +271,9 @@ sub configure
         [ 'Git::Tag'            => { tag_format => 'v%v', tag_message => 'v%v%t' } ],
         $self->server eq 'github' ? [ 'GitHub::Update' => { ':version' => '0.40', metacpan => 1 } ] : (),
 
-        [ 'BumpVersionAfterRelease::Transitional' => { ':version' => '0.004' } ],
+        [ 'BumpVersionAfterRelease::Transitional' => { ':version' => '0.004', global => 1 } ],
         [ 'NextRelease'         => { ':version' => '5.033', time_zone => 'UTC', format => '%-' . ($self->changes_version_columns - 2) . 'v  %{yyyy-MM-dd HH:mm:ss\'Z\'}d%{ (TRIAL RELEASE)}T' } ],
-        [ 'Git::Commit'         => 'post-release commit' => { ':version' => '2.020', allow_dirty => [ 'Changes' ], allow_dirty_match => '^lib/', commit_msg => 'increment $VERSION after release' } ],
+        [ 'Git::Commit'         => 'post-release commit' => { ':version' => '2.020', allow_dirty => [ 'Changes' ], allow_dirty_match => '^lib/.*\.pm$', commit_msg => 'increment $VERSION after release' } ],
         'Git::Push',
     );
 
@@ -371,7 +371,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.091
+version 0.092
 
 =head1 SYNOPSIS
 
@@ -389,6 +389,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     ;;; VersionProvider
     [RewriteVersion::Transitional]
     :version = 0.004
+    global = 1
     fallback_version_provider = Git::NextVersion
     version_regexp = ^v([\d._]+)(-TRIAL)?$
 
@@ -525,9 +526,11 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     directory = demo
 
     [MetaProvides::Package]
-    meta_noindex = 1
     :version = 1.15000002
     finder = :InstallModules
+    meta_noindex = 1
+    inherit_version = 0
+    inherit_missing = 1
 
     [MetaConfig]
     [Keywords]
@@ -637,6 +640,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
 
     [BumpVersionAfterRelease::Transitional]
     :version = 0.004
+    global = 1
     [NextRelease]
     :version = 5.033
     time_zone = UTC
@@ -644,7 +648,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     [Git::Commit / post-release commit]
     :version = 2.020
     allow_dirty = Changes
-    allow_dirty_match = ^lib
+    allow_dirty_match = ^lib/.*\.pm$
     commit_msg = increment $VERSION after release
     [Git::Push]
 
